import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
	const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
	access_token = res.data["access_token"];
	axios_config = {
		headers: { "authorization": "Bearer " + access_token },
		validateStatus: undefined
	};
});


describe('POST /api/cards illegally', () => {
	it('non-existant runner input should return 404', async () => {
		const res = await axios.post(base + '/api/cards', {
			"runner": 999999999999999999999999
		}, axios_config);
		expect(res.status).toEqual(404);
		expect(res.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('POST /api/cards successfully (without runner)', () => {
	it('creating a card with the minimum amount of parameters should return 200', async () => {
		const res = await axios.post(base + '/api/cards', null, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		delete res.data.id;
		delete res.data.code;
		expect(res.data).toEqual({
			"runner": null,
			"enabled": true,
			"responseType": "RUNNERCARD"
		});
	});
	it('creating a disabled card should return 200', async () => {
		const res = await axios.post(base + '/api/cards', {
			"enabled": false
		}, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		delete res.data.id;
		delete res.data.code;
		expect(res.data).toEqual({
			"runner": null,
			"enabled": false,
			"responseType": "RUNNERCARD"
		});
	});
	it('creating a enabled card should return 200', async () => {
		const res = await axios.post(base + '/api/cards', {
			"enabled": true
		}, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		delete res.data.id;
		delete res.data.code;
		expect(res.data).toEqual({
			"runner": null,
			"enabled": true,
			"responseType": "RUNNERCARD"
		});
	});
});
// ---------------
describe('POST /api/cards successfully (with runner)', () => {
	let added_org;
	let added_runner;
	it('creating a new org with just a name should return 200', async () => {
		const res1 = await axios.post(base + '/api/organizations', {
			"name": "test123"
		}, axios_config);
		added_org = res1.data
		expect(res1.status).toEqual(200);
		expect(res1.headers['content-type']).toContain("application/json")
	});
	it('creating a new runner with only needed params should return 200', async () => {
		const res2 = await axios.post(base + '/api/runners', {
			"firstname": "first",
			"lastname": "last",
			"group": added_org.id
		}, axios_config);
		delete res2.data.group;
		added_runner = res2.data;
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('creating a card with the minimum amount of parameters should return 200', async () => {
		const res = await axios.post(base + '/api/cards', {
			"runner": added_runner.id
		}, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		delete res.data.id;
		delete res.data.code;
		expect(res.data).toEqual({
			"runner": added_runner,
			"enabled": true,
			"responseType": "RUNNERCARD"
		});
	});
	it('creating a card with runner (no optional params) should return 200', async () => {
		const res = await axios.post(base + '/api/cards', {
			"runner": added_runner.id
		}, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		delete res.data.id;
		delete res.data.code;
		expect(res.data).toEqual({
			"runner": added_runner,
			"enabled": true,
			"responseType": "RUNNERCARD"
		});
	});
	it('creating a enabled card with runner should return 200', async () => {
		const res = await axios.post(base + '/api/cards', {
			"runner": added_runner.id,
			"enabled": true
		}, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		delete res.data.id;
		delete res.data.code;
		expect(res.data).toEqual({
			"runner": added_runner,
			"enabled": true,
			"responseType": "RUNNERCARD"
		});
	});
	it('creating a disabled card with runner should return 200', async () => {
		const res = await axios.post(base + '/api/cards', {
			"runner": added_runner.id,
			"enabled": false
		}, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		delete res.data.id;
		delete res.data.code;
		expect(res.data).toEqual({
			"runner": added_runner,
			"enabled": false,
			"responseType": "RUNNERCARD"
		});
	});
});