import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port
let access_token;
let axios_config;

beforeAll(async () => {
    const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
    access_token = res.data["access_token"];
    axios_config = {
        headers: { "authorization": "Bearer " + access_token },
        validateStatus: undefined
    };
});

describe('GET /api/contacts', () => {
    it('basic get should return 200', async () => {
        const res = await axios.get(base + '/api/contacts', axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('GET /api/contacts/0', () => {
    it('basic get should return 404', async () => {
        const res = await axios.get(base + '/api/contacts/0', axios_config);
        expect(res.status).toEqual(404);
        expect(res.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('GET /api/contacts after adding', () => {
    let added_contact;
    it('creating a new donor with only needed params should return 200', async () => {
        const res = await axios.post(base + '/api/contacts', {
            "firstname": "first",
            "lastname": "last"
        }, axios_config);
        added_contact = res.data;
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
    it('explicit get should return 200', async () => {
        const res = await axios.get(base + '/api/contacts/' + added_contact.id, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
        let gotten_donor = res.data
        expect(gotten_donor).toEqual(added_contact);
    });
    it('get from all runners should return 200', async () => {
        const res = await axios.get(base + '/api/contacts/', axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
        let gotten_donors = res.data
        expect(gotten_donors).toContainEqual(added_contact);
    });
});