import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
	const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
	access_token = res.data["access_token"];
	axios_config = {
		headers: { "authorization": "Bearer " + access_token },
		validateStatus: undefined
	};
});

describe('GET /api/donations sucessfully', () => {
	it('basic get should return 200', async () => {
		const res = await axios.get(base + '/api/donations', axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('GET /api/donations illegally', () => {
	it('get for non-existant track should return 404', async () => {
		const res = await axios.get(base + '/api/donations/-1', axios_config);
		expect(res.status).toEqual(404);
		expect(res.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('adding + getting fixed donation', () => {
	let added_donor;
	let added_donation;
	it('creating a new donor with only needed params should return 200', async () => {
		const res = await axios.post(base + '/api/donors', {
			"firstname": "first",
			"lastname": "last"
		}, axios_config);
		added_donor = res.data
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('creating a new fixed donation should return 200', async () => {
		const res = await axios.post(base + '/api/donations/fixed', {
			"donor": added_donor.id,
			"amount": 1000
		}, axios_config);
		added_donation = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('check if donation was added (no parameter validation)', async () => {
		const res = await axios.get(base + '/api/donations/' + added_donation.id, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
	});
});
// ---------------
describe('adding + getting distance donation', () => {
	let added_donor;
	let added_org;
	let added_runner;
	let added_donation;
	it('creating a new donor with only needed params should return 200', async () => {
		const res = await axios.post(base + '/api/donors', {
			"firstname": "first",
			"lastname": "last"
		}, axios_config);
		added_donor = res.data
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('creating a new org with just a name should return 200', async () => {
		const res = await axios.post(base + '/api/organizations', {
			"name": "test123"
		}, axios_config);
		added_org = res.data
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('creating a new runner with only needed params should return 200', async () => {
		const res = await axios.post(base + '/api/runners', {
			"firstname": "first",
			"lastname": "last",
			"group": added_org.id
		}, axios_config);
		added_runner = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('creating a new fixed donation should return 200', async () => {
		const res = await axios.post(base + '/api/donations/distance', {
			"runner": added_runner.id,
			"amountPerDistance": 100,
			"donor": added_donor.id
		}, axios_config);
		added_donation = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('check if donation was added (no parameter validation)', async () => {
		const res = await axios.get(base + '/api/donations/' + added_donation.id, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
	});
});