import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
    const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
    access_token = res.data["access_token"];
    axios_config = {
        headers: { "authorization": "Bearer " + access_token },
        validateStatus: undefined
    };
});

describe('adding + deletion (non-existant)', () => {
    it('delete', async () => {
        const res2 = await axios.delete(base + '/api/donors/0', axios_config);
        expect(res2.status).toEqual(204);
    });
});
// ---------------
describe('add+delete', () => {
    let added_donor;
    it('creating a new donor with only needed params should return 200', async () => {
        const res2 = await axios.post(base + '/api/donors', {
            "firstname": "first",
            "lastname": "last"
        }, axios_config);
        added_donor = res2.data;
        expect(res2.status).toEqual(200);
        expect(res2.headers['content-type']).toContain("application/json")
    });
    it('delete donor', async () => {
        const res3 = await axios.delete(base + '/api/donors/' + added_donor.id, axios_config);
        expect(res3.status).toEqual(200);
        expect(res3.headers['content-type']).toContain("application/json")
        let deleted_runner = res3.data
        expect(deleted_runner).toEqual(added_donor);
    });
    it('check if donor really was deleted', async () => {
        const res4 = await axios.get(base + '/api/donors/' + added_donor.id, axios_config);
        expect(res4.status).toEqual(404);
        expect(res4.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('DELETE donor with donations invalid', () => {
    let added_donor;
    let added_org;
    let added_runner;
    it('creating a new donor with only needed params should return 200', async () => {
        const res = await axios.post(base + '/api/donors', {
            "firstname": "first",
            "lastname": "last"
        }, axios_config);
        added_donor = res.data
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
    it('creating a new org with just a name should return 200', async () => {
        const res = await axios.post(base + '/api/organizations', {
            "name": "test123"
        }, axios_config);
        added_org = res.data
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
    it('creating a new runner with only needed params should return 200', async () => {
        const res = await axios.post(base + '/api/runners', {
            "firstname": "first",
            "lastname": "last",
            "group": added_org.id
        }, axios_config);
        added_runner = res.data;
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
    it('creating a new fixed donation should return 200', async () => {
        const res = await axios.post(base + '/api/donations/fixed', {
            "donor": added_donor.id,
            "amount": 1000
        }, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
    it('creating a new distance donation should return 200', async () => {
        const res = await axios.post(base + '/api/donations/distance', {
            "runner": added_runner.id,
            "amountPerDistance": 100,
            "donor": added_donor.id
        }, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
    it('delete donor w/o force', async () => {
        const res = await axios.delete(base + '/api/donors/' + added_donor.id, axios_config);
        expect(res.status).toEqual(406);
        expect(res.headers['content-type']).toContain("application/json")
    });
});
// ---------------
describe('DELETE donor with donations valid', () => {
    let added_donor;
    let added_org;
    let added_runner;
    it('creating a new donor with only needed params should return 200', async () => {
        const res = await axios.post(base + '/api/donors', {
            "firstname": "first",
            "lastname": "last"
        }, axios_config);
        added_donor = res.data
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
    it('creating a new org with just a name should return 200', async () => {
        const res = await axios.post(base + '/api/organizations', {
            "name": "test123"
        }, axios_config);
        added_org = res.data
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
    it('creating a new runner with only needed params should return 200', async () => {
        const res = await axios.post(base + '/api/runners', {
            "firstname": "first",
            "lastname": "last",
            "group": added_org.id
        }, axios_config);
        added_runner = res.data;
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
    it('creating a new fixed donation should return 200', async () => {
        const res = await axios.post(base + '/api/donations/fixed', {
            "donor": added_donor.id,
            "amount": 1000
        }, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
    it('creating a new distance donation should return 200', async () => {
        const res = await axios.post(base + '/api/donations/distance', {
            "runner": added_runner.id,
            "amountPerDistance": 100,
            "donor": added_donor.id
        }, axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
    it('delete donor w/ force ', async () => {
        const res = await axios.delete(base + '/api/donors/' + added_donor.id + "?force=true", axios_config);
        expect(res.status).toEqual(200);
        expect(res.headers['content-type']).toContain("application/json")
    });
});