import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
	const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
	access_token = res.data["access_token"];
	axios_config = {
		headers: { "authorization": "Bearer " + access_token },
		validateStatus: undefined
	};
});

// ---------------
describe('DETELE track', () => {
	let added_track
	it('creating a track with the minimum amount of parameters should return 200', async () => {
		const res = await axios.post(base + '/api/tracks', {
			"name": "testtrack",
			"distance": 200,
		}, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		added_track = res.data
	});
	it('delete track', async () => {
		const res2 = await axios.delete(base + '/api/tracks/' + added_track.id, axios_config);
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
		let deleted_track = res2.data
		delete deleted_track.id;
		expect(res2.data).toEqual({
			"name": "testtrack",
			"distance": 200,
			"minimumLapTime": null,
			"responseType": "TRACK"
		});
	});
	it('check if track really was deleted', async () => {
		const res3 = await axios.get(base + '/api/tracks/' + added_track.id, axios_config);
		expect(res3.status).toEqual(404);
		expect(res3.headers['content-type']).toContain("application/json")
	});
});
// ---------------
describe('DELETE track (non-existant)', () => {
	it('delete', async () => {
		const res2 = await axios.delete(base + '/api/tracks/0', axios_config);
		expect(res2.status).toEqual(204);
	});
});
