import axios from 'axios';
import { config } from '../../config';
const base = "http://localhost:" + config.internal_port

let access_token;
let axios_config;

beforeAll(async () => {
	const res = await axios.post(base + '/api/auth/login', { username: "demo", password: "demo" });
	access_token = res.data["access_token"];
	axios_config = {
		headers: { "authorization": "Bearer " + access_token },
		validateStatus: undefined
	};
});

describe('adding + updating illegally', () => {
	let added_org;
	let added_runner;
	let added_card;
	let added_track;
	let added_station;
	let added_scan;
	it('creating a new org with just a name should return 200', async () => {
		const res1 = await axios.post(base + '/api/organizations', {
			"name": "test123"
		}, axios_config);
		added_org = res1.data
		expect(res1.status).toEqual(200);
		expect(res1.headers['content-type']).toContain("application/json")
	});
	it('creating a new runner with only needed params should return 200', async () => {
		const res2 = await axios.post(base + '/api/runners', {
			"firstname": "first",
			"lastname": "last",
			"group": added_org.id
		}, axios_config);
		added_runner = res2.data;
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('creating a card with the minimum amount of parameters should return 200', async () => {
		const res = await axios.post(base + '/api/cards', {
			"runner": added_runner.id
		}, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		added_card = res.data;
	});
	it('creating a track should return 200', async () => {
		const res1 = await axios.post(base + '/api/tracks', {
			"name": "test123",
			"distance": 123,
			"minimumLapTime": 30
		}, axios_config);
		added_track = res1.data
		expect(res1.status).toEqual(200);
		expect(res1.headers['content-type']).toContain("application/json")
	});
	it('correct description and track input for station creation return 200', async () => {
		const res = await axios.post(base + '/api/stations', {
			"track": added_track.id,
			"description": "I am but a simple test."
		}, axios_config);
		added_station = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('creating a scan should return 200', async () => {
		const res = await axios.post(base + '/api/scans/trackscans', {
			"card": added_card.id,
			"station": added_station.id
		}, {
			headers: { "authorization": "Bearer " + added_station.key },
			validateStatus: undefined
		});
		added_scan = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
	});
	it('updating empty should return 400', async () => {
		const res2 = await axios.put(base + '/api/scans/trackscans/' + added_scan.id, null, axios_config);
		expect(res2.status).toEqual(400);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('updating with wrong id should return 406', async () => {
		const res2 = await axios.put(base + '/api/scans/trackscans/' + added_scan.id, {
			"id": added_scan.id + 1,
			"station": added_station.id,
			"runner": added_runner.id
		}, axios_config);
		expect(res2.status).toEqual(406);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('updating with invalid station should return 404', async () => {
		const res2 = await axios.put(base + '/api/scans/trackscans/' + added_scan.id, {
			"id": added_scan.id,
			"station": 9999999999999999,
			"runner": added_runner.id
		}, axios_config);
		expect(res2.status).toEqual(404);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('updating with invalid runner should return 404', async () => {
		const res2 = await axios.put(base + '/api/scans/trackscans/' + added_scan.id, {
			"id": added_scan.id,
			"station": added_station.id,
			"runner": 9999999999999999999
		}, axios_config);
		expect(res2.status).toEqual(404);
		expect(res2.headers['content-type']).toContain("application/json")
	});
});
//---------------
describe('adding + updating successfilly', () => {
	let added_org;
	let added_runner;
	let added_runner2;
	let added_card;
	let added_track;
	let added_track2;
	let added_station;
	let added_station2;
	let added_scan;
	it('creating a new org with just a name should return 200', async () => {
		const res1 = await axios.post(base + '/api/organizations', {
			"name": "test123"
		}, axios_config);
		added_org = res1.data
		expect(res1.status).toEqual(200);
		expect(res1.headers['content-type']).toContain("application/json")
	});
	it('creating a new runner with only needed params should return 200', async () => {
		const res2 = await axios.post(base + '/api/runners', {
			"firstname": "first",
			"lastname": "last",
			"group": added_org.id
		}, axios_config);
		added_runner = res2.data;
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('creating a new runner with only needed params should return 200', async () => {
		const res2 = await axios.post(base + '/api/runners', {
			"firstname": "first",
			"lastname": "last",
			"group": added_org.id
		}, axios_config);
		added_runner2 = res2.data;
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('creating a card with the minimum amount of parameters should return 200', async () => {
		const res = await axios.post(base + '/api/cards', {
			"runner": added_runner.id
		}, axios_config);
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
		added_card = res.data;
	});
	it('creating a track should return 200', async () => {
		const res1 = await axios.post(base + '/api/tracks', {
			"name": "test123",
			"distance": 123,
			"minimumLapTime": 30
		}, axios_config);
		added_track = res1.data
		expect(res1.status).toEqual(200);
		expect(res1.headers['content-type']).toContain("application/json")
	});
	it('creating a track should return 200', async () => {
		const res1 = await axios.post(base + '/api/tracks', {
			"name": "test123",
			"distance": 123,
			"minimumLapTime": 30
		}, axios_config);
		added_track2 = res1.data
		expect(res1.status).toEqual(200);
		expect(res1.headers['content-type']).toContain("application/json")
	});
	it('correct description and track input for station creation return 200', async () => {
		const res = await axios.post(base + '/api/stations', {
			"track": added_track.id,
			"description": "I am but a simple test."
		}, axios_config);
		added_station = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('correct description and track input for station creation return 200', async () => {
		const res = await axios.post(base + '/api/stations', {
			"track": added_track.id,
			"description": "I am but a simple test."
		}, axios_config);
		added_station2 = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json")
	});
	it('creating a scan should return 200', async () => {
		const res = await axios.post(base + '/api/scans/trackscans', {
			"card": added_card.id,
			"station": added_station.id
		}, {
			headers: { "authorization": "Bearer " + added_station.key },
			validateStatus: undefined
		});
		added_scan = res.data;
		expect(res.status).toEqual(200);
		expect(res.headers['content-type']).toContain("application/json");
	});
	it('updating with new runner should return 200', async () => {
		const res2 = await axios.put(base + '/api/scans/trackscans/' + added_scan.id, {
			"id": added_scan.id,
			"station": added_station.id,
			"runner": added_runner2.id
		}, axios_config);
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('updating with new station should return 200', async () => {
		const res2 = await axios.put(base + '/api/scans/trackscans/' + added_scan.id, {
			"id": added_scan.id,
			"station": added_station2.id,
			"runner": added_runner.id
		}, axios_config);
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
	});
	it('updating with valid=false should return 200', async () => {
		const res2 = await axios.put(base + '/api/scans/trackscans/' + added_scan.id, {
			"id": added_scan.id,
			"station": added_station2.id,
			"runner": added_runner.id,
			"valid": false
		}, axios_config);
		expect(res2.status).toEqual(200);
		expect(res2.headers['content-type']).toContain("application/json")
	});
});
